<?php

namespace Drupal\brevo;

/**
 * The interface for Brevo handler service.
 */
interface BrevoHandlerInterface {

  const CONFIG_NAME = 'brevo.settings';

  /**
   * Connects to Brevo API and sends out the email.
   *
   * @param array $brevoMessage
   *   A message array, as described in
   *   https://developers.brevo.com/docs/send-a-transactional-email.
   *
   * @return bool
   *   TRUE if the mail was successfully accepted by the API, FALSE otherwise.
   *
   * @see https://developers.brevo.com/docs/send-a-transactional-email
   */
  public function sendMail(array $brevoMessage);

  /**
   * Validates Brevo library and API settings.
   *
   * @param bool $showMessage
   *   Whether error messages should be shown.
   *
   * @return bool
   *   Whether the library installed and API settings are ok.
   */
  public function moduleStatus($showMessage = FALSE);

  /**
   * Validates Brevo API key.
   *
   * @param string $key
   *   The API key.
   *
   * @return bool
   *   Whether the API key is valid.
   */
  public function validateBrevoApiKey($key);

  /**
   * Checks if Brevo's drupal dependencies are properly installed.
   *
   * @param bool $showMessage
   *   Whether error messages should be shown.
   *
   * @return bool
   *   Whether Drupal modules dependencies are properly installed.
   */
  public function validateDrupalMailerLibrary($showMessage = FALSE);

  /**
   * Checks if API settings are correct and not empty.
   *
   * @param bool $showMessage
   *   Whether error messages should be shown.
   *
   * @return bool
   *   Whether API settings are valid.
   */
  public function validateBrevoApiSettings($showMessage = FALSE);

  /**
   * Checks if Brevo PHP SDK is installed correctly.
   *
   * @param bool $showMessage
   *   Whether error messages should be shown.
   *
   * @return bool
   *   Whether the Brevo PHP SDK is installed correctly.
   */
  public function validateBrevoLibrary($showMessage = FALSE);

}
