<?php

namespace Drupal\brevo\Plugin\QueueWorker;

use Drupal\brevo\BrevoHandlerInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides base functionality for the SendMail Queue Workers.
 */
class SendMailBase extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * Brevo config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $brevoConfig;

  /**
   * Brevo Logger instance.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * Brevo mail handler.
   *
   * @var \Drupal\brevo\BrevoHandlerInterface
   */
  protected $brevoHandler;

  /**
   * SendMailBase constructor.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ImmutableConfig $settings, LoggerInterface $logger, BrevoHandlerInterface $brevo_handler) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->brevoConfig = $settings;
    $this->logger = $logger;
    $this->brevoHandler = $brevo_handler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory')->get(BrevoHandlerInterface::CONFIG_NAME),
      $container->get('logger.factory')->get('brevo'),
      $container->get('brevo.mail_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    $result = $this->brevoHandler->sendMail($data->message);

    if ($this->brevoConfig->get('debug_mode')) {
      $this->logger->notice('Successfully sent message on CRON from %from to %to.',
        [
          '%from' => $data->message['from'],
          '%to' => $data->message['to'],
        ]
      );
    }

    if (!$result) {
      throw new \Exception('Brevo: email did not pass through API.');
    }
  }

}
